package org.crosswire.common.swing.plaf;

import java.awt.Component;
import java.awt.Graphics;
import java.awt.Insets;
import javax.swing.border.AbstractBorder;
import javax.swing.plaf.UIResource;
import javax.swing.plaf.metal.MetalLookAndFeel;


/**
 * A class that provides a border that matches MetalBorders.ScrollPaneBorder.
 */
public final class MetalPanelBorder extends AbstractBorder implements UIResource
{
    private int insetTop = 1;
    private int insetLeft = 1;
    private int insetBottom = 2;
    private int insetRight = 2;
    
    private int flags = 0;
    public static int TOP = 1;
    public static int LEFT = 2;
    public static int BOTTOM = 4;
    public static int RIGHT = 8;
        
    private Insets insets = null;
    
    public MetalPanelBorder()
    {
        insets = new Insets(insetTop, insetLeft, insetBottom, insetRight);
    }   
    
    /**
     * Create a MetalPanelBorder instance where the border visbility 
     * (top, left, bottom and right border) is controlled by the bit mask 
     * <CODE>borderFlags</CODE>
     * @param borderFlags Match flags, a bit mask that may include TOP, LEFT, BOTTOM, and RIGHT
     */
    public MetalPanelBorder(int borderFlags) 
    {
        flags = 0 | borderFlags;

        if ((flags & TOP) != TOP) 
        {
            insetTop = 0;
        }
        
        if ((flags & LEFT) != LEFT) 
        {
            insetLeft = 0;
        }
        
        if ((flags & BOTTOM) != BOTTOM) 
        {
            insetBottom = 0;
        }
        
        if ((flags & RIGHT) != RIGHT) 
        {
            insetRight = 0;
        }
        
        insets = new Insets(insetTop, insetLeft, insetBottom, insetRight);
    }
    
    public void paintBorder(Component c, Graphics g, int x, int y, int w, int h) 
    {
        g.translate( x, y);

        if ((flags & TOP) == TOP) 
        {
            g.setColor( MetalLookAndFeel.getControlDarkShadow() );
            g.drawLine(0, 0, w-2, 0);
        }
        
        if ((flags & LEFT) == LEFT)
        {
            g.drawLine(0, 0, 0, h-2);
        }
        
        if ((flags & BOTTOM) == BOTTOM)
        {
            g.drawLine(0, h-2, w-2, h-2);
            g.setColor( MetalLookAndFeel.getControlHighlight() );
            g.drawLine(1, h-1, w-1, h-1);
        }
        
        if ((flags & RIGHT) == RIGHT)
        {
            g.setColor( MetalLookAndFeel.getControlDarkShadow() );
            g.drawLine(w-2, h-2, w-2, 0);
            g.setColor( MetalLookAndFeel.getControlHighlight() );
            g.drawLine(w-1, h-1, w-1, 1);
        }
        
        g.translate( -x, -y);
    }

    public Insets getBorderInsets(Component c)
    {
        return insets;
    }
}
